==> haskell-critbit-0.2.0.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: critbit
version: 0.2.0.0
id: critbit-0.2.0.0-8eIktk1DYx6JTD7vUxgZgF
key: critbit-0.2.0.0-8eIktk1DYx6JTD7vUxgZgF
license: BSD3
copyright: 2013-2014 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/critbit
synopsis: Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').
    .
    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.
    .
    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.
category: Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules: Data.CritBit.Core Data.CritBit.Types.Internal
                Data.CritBit.Tree
abi: a3e31ab71baead055493c1e7058242fd
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/critbit-0.2.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/critbit-0.2.0.0
hs-libraries: HScritbit-0.2.0.0-8eIktk1DYx6JTD7vUxgZgF
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html: /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-critbit-0.2.0.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: critbit
version: 0.2.0.0
id: critbit-0.2.0.0-G5zQ7RoTicJ7geCzptapcu
key: critbit-0.2.0.0-G5zQ7RoTicJ7geCzptapcu
license: BSD3
copyright: 2013-2014 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/critbit
synopsis: Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').
    .
    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.
    .
    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.
category: Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules: Data.CritBit.Core Data.CritBit.Types.Internal
                Data.CritBit.Tree
abi: 4be3a381e5562c5ae39fe925a129b864
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/critbit-0.2.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/critbit-0.2.0.0
hs-libraries: HScritbit-0.2.0.0-G5zQ7RoTicJ7geCzptapcu
depends:
    array-0.5.2.0 base-4.10.0.0 bytestring-0.10.8.2 deepseq-1.4.3.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: array-0.5.2.0=044554210403f250e868a2183de060a9
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
haddock-interfaces: /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html: /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
